@@ -7,15 +7,15 @@ use experimental 'smartmatch';
 extends 'Data::Sah::Compiler::perl::TH';
 with 'Data::Sah::Type::num';
 
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 sub handle_type {
     my ($self, $cd) = @_;
     my $c = $self->compiler;
     my $dt = $cd->{data_term};
 
-    $c->add_module($cd, 'Scalar::Util');
-    $cd->{_ccl_check_type} = "Scalar::Util::looks_like_number($dt)";
+    $c->add_module($cd, 'Scalar::Util::Numeric');
+    $cd->{_ccl_check_type} = "Scalar::Util::Numeric::isnum($dt)";
 }
 
 sub superclause_comparable {
@@ -79,7 +79,7 @@ Data::Sah::Compiler::perl::TH::num - perl's type handler for type "num"
 
 =head1 VERSION
 
-This document describes version 0.28 of Data::Sah::Compiler::perl::TH::num (from Perl distribution Data-Sah), released on 2014-05-17.
+This document describes version 0.29 of Data::Sah::Compiler::perl::TH::num (from Perl distribution Data-Sah), released on 2014-06-30.
 
 =for Pod::Coverage ^(clause_.+|superclause_.+)$
 
